@@ -7,6 +7,8 @@ FASHION_TAGGING_ENDPOINT = "tagging/fashion/v2/tags"
 META_FASHION_TAGGING_ENDPOINT = "tagging/fashion/v2/meta"
 GENERIC_TAGGING_ENDPOINT = "tagging/generic/v2/tags"
 HOME_DECOR_TAGGING_ENDPOINT = "tagging/homedecor/v2/tags"
+DETECT_FASHION_TAGGING_ENDPOINT = "tagging/fashion/v2/detect_tags"
+DETECT_FASHION_ENDPOINT = "tagging/fashion/v2/detect"
 
 
 class TaggingClient(RestClient):
@@ -53,6 +55,12 @@ class FashionTaggingClient(TaggingClient):
     def meta_tags(self, records, profile=None):
         return super().tags(records, META_FASHION_TAGGING_ENDPOINT, aggregate_labels=False, profile=profile)
 
+    def detect(self, records, profile=None):
+        return super().tags(records, DETECT_FASHION_ENDPOINT, aggregate_labels=False, profile=profile)
+
+    def detect_tags(self, records, profile=None):
+        return super().tags(records, DETECT_FASHION_TAGGING_ENDPOINT, aggregate_labels=False, profile=profile)
+
     def get_top_categories(self):
         result = requests.get(self.urljoin(self.endpoint, "tagging/fashion/v2/top_categories"))
         return result.json()["labels"]
